{% load cms_tags staticfiles sekizai_tags thumbnail %}

<div class="content-plugin icon-plugin {{ instance.css_classes }}">
    <i class="icon-plugin__icon icon-plugin__icon--{{instance.icon}}" aria-hidden="true"></i>
</div>
