{% load cms_tags staticfiles sekizai_tags thumbnail allink_user_tags %}

    {% if request.user|in_one_group:instance.groups.all or request.user.is_staff %}
            <div class="app-content-plugin group-plugin">
                <header class="group-plugin__heading-container" data-accordion-trigger>
                    <h2 class="group-plugin__heading">
                        <a data-toggle="collapse" href="#group-content-{{instance.id}}" aria-expanded="false" aria-controls="group-content-{{instance.id}}" class="group-plugin__link collapsed" data-collapse-toggle>
                            {{ instance.title }}
                        </a>
                       </h2>
                </header>
                {% for plugin in instance.child_plugin_instances %}
                    {% render_plugin plugin %}
                {% endfor %}
            </div>
    {% endif %}
