{% load cms_tags sekizai_tags i18n thumbnail %}

<div class="collapse" id="group-content-{{instance.parent.id}}">
    <div class="group-child-plugin">
         <div class="manage-spacings">
             <div class="group-child-plugin__heading-container">
                 <h3 class="group-child-plugin__heading">{{ instance.title }}</h3>
             </div>
             <div class="group-child-plugin__list-container">
                 <ul class="group-child-plugin__list">
                      {% for plugin in instance.child_plugin_instances %}
                         <li class="group-child-plugin__list-item">{% render_plugin plugin %}</li>
                     {% endfor %}
                 </ul>
             </div>
         </div>
     </div>
 </div>
